==> Java-Swing-0.02.tar.gz: Java-Swing-0.02/java/PerlWindowFocusListener.java <==
import java.awt.event.WindowFocusListener;
import org.perl.inline.java.*;

public class      PerlWindowFocusListener
       extends    InlineJavaPerlCaller
       implements WindowFocusListener
{
    String sender;
    String callbacks;

    public PerlWindowFocusListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void windowGainedFocus(java.awt.event.WindowEvent event) {
        try {
            CallPerl(
                "Java::Swing::WindowFocusListener",
                "_WindowFocusListener",
                new Object[] {sender, callbacks, "windowGainedFocus", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void windowLostFocus(java.awt.event.WindowEvent event) {
        try {
            CallPerl(
                "Java::Swing::WindowFocusListener",
                "_WindowFocusListener",
                new Object[] {sender, callbacks, "windowLostFocus", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.11.tar.gz: Java-Swing-0.11/java/PerlWindowFocusListener.java <==
import java.awt.event.WindowFocusListener;
import org.perl.inline.java.*;

public class      PerlWindowFocusListener
       extends    InlineJavaPerlCaller
       implements WindowFocusListener
{
    String sender;
    String callbacks;

    public PerlWindowFocusListener() throws InlineJavaException { }

    public PerlWindowFocusListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void windowGainedFocus(java.awt.event.WindowEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "windowGainedFocus", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void windowLostFocus(java.awt.event.WindowEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "windowLostFocus", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
